import { Controller, Get, Query, Post, Body } from '@nestjs/common'
import { ApiOperation, ApiTags } from '@nestjs/swagger'

import {
  GetModuleListDto,
  GetModuleConfigurationDto,
  SaveModuleConfigurationDto,
  DeleteModuleConfigurationDto
} from '@/dto/agent-module'

import { AgentModuleService } from './service/agent-module.service'

@ApiTags('agent-module')
@Controller('agent-module')
export class AgentModuleController {
  constructor(private readonly agentModuleService: AgentModuleService) {}

  @Get('get-module-list')
  @ApiOperation({ summary: '获取模块列表' })
  async getModuleList(@Query() query: GetModuleListDto) {
    return this.agentModuleService.getModuleList(query.page, query.pageSize)
  }

  @Get('get-module-configuration')
  @ApiOperation({ summary: '获取模块配置' })
  async getModuleConfiguration(@Query() query: GetModuleConfigurationDto) {
    return this.agentModuleService.getModuleConfiguration(query.moduleId)
  }

  @Post('save-module-configuration')
  @ApiOperation({ summary: '保存模块配置' })
  async saveModuleConfiguration(@Body() body: SaveModuleConfigurationDto) {
    return this.agentModuleService.saveModuleConfiguration(
      body.moduleId,
      body.name,
      body.displayName,
      body.type,
      body.agentId
    )
  }

  @Get('get-module-agent-types')
  @ApiOperation({ summary: '获取模块代理类型' })
  async getModuleAgentTypes() {
    return this.agentModuleService.getModuleAgentTypes()
  }

  @Post('delete-module-configuration')
  @ApiOperation({ summary: '删除模块配置' })
  async deleteModuleConfiguration(@Body() body: DeleteModuleConfigurationDto) {
    return this.agentModuleService.deleteModuleConfiguration(body.moduleId)
  }
}
